@@ -87,7 +87,7 @@ exports.handler = async function(event) {
   }
   let labels = {};
   payload.workflow_job.labels.forEach((l) => labels[l] = true);
-  let executionName = `${payload.repository.full_name.replace("/", "-")}-${event.headers["x-github-delivery"]}`;
+  let executionName = `${payload.repository.full_name.replace("/", "-")}-${event.headers["x-github-delivery"]}`.slice(0, 64);
   const execution = await sf.startExecution({
     stateMachineArn: process.env.STEP_FUNCTION_ARN,
     input: JSON.stringify({
